==> kdeutils-4.1.1.tar.bz2: kdeutils-4.1.1/okteta/program/oktetakakao/io/kabstractbytearraystreamencoder.h <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KABSTRACTBYTEARRAYSTREAMENCODER_H
#define KABSTRACTBYTEARRAYSTREAMENCODER_H

// Kakao core
#include <abstractmodelstreamencoder.h>

namespace KHEUI {
class KByteArrayView;
}
namespace KHECore {
class KAbstractByteArrayModel;
}
namespace KHE {
class KSection;
}

class KAbstractByteArrayStreamEncoder : public AbstractModelStreamEncoder
{
    Q_OBJECT

  public:
    KAbstractByteArrayStreamEncoder( const QString &remoteTypeName, const QString &remoteMimeType );
    virtual ~KAbstractByteArrayStreamEncoder();

  public: // AbstractModelStreamEncoder API
    virtual bool encodeToStream( QIODevice *device, AbstractModel *model, const AbstractModelSelection *selection );
    virtual QString modelTypeName( AbstractModel *model, const AbstractModelSelection *selection ) const;

  protected: // API to be implemented
    virtual bool encodeDataToStream( QIODevice *device,
                                     const KHEUI::KByteArrayView *byteArrayView,
                                     const KHECore::KAbstractByteArrayModel *byteArrayModel,
                                     const KHE::KSection &section ) = 0;
};

#endif

==> kdeutils-4.3.4.tar.bz2: kdeutils-4.3.4/okteta/program/oktetakakao/io/kabstractbytearraystreamencoder.h <==
/*
    This file is part of the Okteta Kakao module, part of the KDE project.

    Copyright 2007 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef KABSTRACTBYTEARRAYSTREAMENCODER_H
#define KABSTRACTBYTEARRAYSTREAMENCODER_H

// Kakao core
#include <abstractmodelstreamencoder.h>

class KByteArrayDisplay;
namespace KHECore {
class AbstractByteArrayModel;
}
namespace KHE {
class Section;
}

class KAbstractByteArrayStreamEncoder : public AbstractModelStreamEncoder
{
    Q_OBJECT

  public:
    KAbstractByteArrayStreamEncoder( const QString &remoteTypeName, const QString &remoteMimeType );
    virtual ~KAbstractByteArrayStreamEncoder();

  public: // AbstractModelStreamEncoder API
    virtual bool encodeToStream( QIODevice *device, AbstractModel *model, const AbstractModelSelection *selection );
    virtual QString modelTypeName( AbstractModel *model, const AbstractModelSelection *selection ) const;

  public:
    QString previewData( AbstractModel* model, const AbstractModelSelection* selection );

  Q_SIGNALS:
    void settingsChanged();

  protected: // API to be implemented
    virtual bool encodeDataToStream( QIODevice *device,
                                     const KByteArrayDisplay* byteArrayView,
                                     const KHECore::AbstractByteArrayModel *byteArrayModel,
                                     const KHE::Section &section ) = 0;
};

#endif
